#define HAVE_BZIP2_SUPPORT 1

/* Set to 1 if the libbz2 functions need the BZ2_ prefix */
#define NEED_BZ2_PREFIX 1

/* Set to 1 if you have xz */
#define HAVE_XZ_SUPPORT 1

/* Set to 1 if you have openssl */
#define HAVE_OPENSSL_SUPPORT 1

/* Set to 1 if you have zstd */
#define HAVE_ZSTD_SUPPORT 1

